from __future__ import annotations
from fastapi import FastAPI, Body
from pydantic import BaseModel
from typing import Tuple, List, Dict
import json
import os


OUTPUT_DIR = "./temp/"
MAP_NAME = "map.txt"
TAG_LIST_NAME = "tags.json"

app = FastAPI()


class MapData(BaseModel):
    esri: str
    arucos: List[Dict]


@app.post("/map")
async def post_map(the_map: MapData):
    result = write_map(the_map)
    return {"success": result}


def write_map(map_data: MapData):
    dir_name = os.getenv("ESRI_OUTPUT_DIRECTORY", default=OUTPUT_DIR)
    if not os.path.exists(dir_name) or not os.path.isdir(dir_name):
        os.makedirs(dir_name, exist_ok=True)
    map_filename = path_join(dir_name, MAP_NAME)
    tag_filename = path_join(dir_name, TAG_LIST_NAME)
    with open(map_filename, 'w') as map_file, \
         open(tag_filename, 'w') as tag_file:
        map_file.write(map_data.esri)
        jdic = {
            "tags": map_data.arucos
        }
        json.dump(jdic, tag_file, indent=4)
    return True


def path_join(p, f):
    return os.path.join(p, f)


